intelmq.bots.collectors.calidog package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.collectors.calidog package

## Submodules

## intelmq.bots.collectors.calidog.collector_certstream module

A Bot to collect data from the Certificate Transparency Log (CTL) This bot works based on certstream library (https://github.com/CaliDog/certstream-python) @author: Florian Krenn, Christoph Giese (Telekom Security) No parameters necessary.

`intelmq.bots.collectors.calidog.collector_certstream.` `BOT`

  alias of `intelmq.bots.collectors.calidog.collector_certstream.CertstreamCollectorBot`

class `intelmq.bots.collectors.calidog.collector_certstream.` `CertstreamCollectorBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.CollectorBot`

  Collect information from CertStream certificate transparency logs

  `callback`(message, context=None)
  `init`()
  `process`()
  `send_update`(message)

## Module contents